@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2018, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -19,16 +19,16 @@
 package georegression.struct.so;
 
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.fail;
 
 /**
  * @author Peter Abeles
  */
-class TestSpecialOrthogonalOps_F64 {
+public class TestSpecialOrthogonalOps_F64 {
 	@Test
-	public void bestFit() {
+	void bestFit() {
 		fail("implement");
 	}
 }
\ No newline at end of file
